get_citation: get_citation

View source: R/zen4R_citation.R

get_citationR Documentation

get_citation

Description

get_citation allows to get the styled citation for Zenodo record, identified by its DOI or concept DOI, and the style name

Usage

get_citation(
  doi,
  sandbox = FALSE,
  style = c("havard-cite-them-right", "apa", "modern-language-association", "vancouver",
    "chicago-fullnote-bibliography", "ieee", "bibtex"),
  logger = NULL
)

Arguments

doi

a Zenodo DOI or concept DOI

sandbox

Use the sandbox infrastructure. Default is FALSE

style

the style character string among. Possible values "havard-cite-them-right", "apa", "modern-language-association","vancouver","chicago-fullnote-bibliography", "ieee", or "bibtex".

logger

a logger to print messages. The logger can be either NULL, "INFO" (with minimum logs), or "DEBUG" (for complete curl http calls logs)

Value

an object of class data.frame giving the record versions including date, version number and version-specific DOI.

the record citation

Examples

## Not run: 
 get_citation(doi = "10.5281/zenodo.2547036", style = "ieee")

## End(Not run)
 

zen4R documentation built on March 30, 2026, 9:07 a.m.