ZenodoRecord
ZenodoRecordObject of R6Class for modelling an ZenodoRecord
R6Class object.
new()This method is used to instantiate a Zenodo Record
prereserveDOI(prereserve)Set prereserve_doi if TRUE, FALSE otherwise to create a record without
prereserved DOI by Zenodo. By default, this method will be called to prereserve a DOI
assuming the record created doesn't yet handle a DOI. To avoid prereserving a DOI
call $prereserveDOI(FALSE) on your record.
setUploadType(uploadType)Set the upload type (mandatory). Value should be among the following: 'publication', 'poster','presentation','dataset','image','video', or 'software'
setPublicationType(publicationType)Set the publication type (mandatory if upload type is 'publication'). Value should be among the following: 'book','section','conferencepaper','article','patent','preprint', 'report','softwaredocumentation','thesis','technicalnote','workingpaper', or 'other'
setImageType(imageType)Set the image type (mandatory if image type is 'image'). Value should be among the following: 'figure','plot','drawing','diagram','photo', or 'other'
setPublicationDate(publicationDate)Set the publication date, as object of class Date
setEmbargoDate(embargoDate)Set the embargo date, as object of class Date
setTitle(title)Set title
setDescription(description)Set description
setAccessRight(accessRight)Set the access right. Value should be among the following: 'open','embargoed', 'restricted','closed'
setAccessConditions(accessConditions)Set access conditions.
addCreator(firsname, lastname, affiliation, orcid, gnd)Add a creator for the record.
removeCreator(by,property)Removes a creator by a property. The by parameter should be the name
of the creator property ('name' - in the form 'lastname, firstname', 'affiliation',
'orcid' or 'gnd'). Returns TRUE if some creator was removed,
FALSE otherwise.
removeCreatorByName(name)Removes a creator by name. Returns TRUE if some creator was removed,
FALSE otherwise.
removeCreatorByAffiliation(affiliation)Removes a creator by affiliation. Returns TRUE if some creator was removed,
FALSE otherwise.
removeCreatorByORCID(orcid)Removes a creator by ORCID. Returns TRUE if some creator was removed,
FALSE otherwise.
setLicense(licenseId)Set license. The license should be set with the Zenodo id of the license. If not
recognized by Zenodo, the function will return an error. The list of licenses can
fetched with the ZenodoManager and the function $getLicenses().
setDOI(doi)Set the DOI. This method can be used if a DOI has been already assigned outside Zenodo.
This method will call the method $prereserveDOI(FALSE).
setVersion(version)Set the version.
setLanguage(language)Set the language ISO 639-2 or 639-3 code.
addRelatedIdentifier(relation, identifier)Adds a related identifier with a given relation. Relation can be one of among following values: isCitedBy, cites, isSupplementTo, isSupplementedBy, isNewVersionOf, isPreviousVersionOf, isPartOf, hasPart, compiles, isCompiledBy, isIdenticalTo, isAlternateIdentifier
Remove a related identifier
setKeywords(keywords)Set a vector of character strings as keywords
addKeyword(keyword)Adds a keyword to the record metadata. Return TRUE if added,
FALSE otherwise.
removedKeyword(keyword)Removes a keyword from the record metadata. Return TRUE if removed,
FALSE otherwise.
addSubject(term, identifier)Add a Subject for the record.
removeSubject(by,property)Removes a subject by a property. The by parameter should be the name
of the subject property ('term' or 'identifier'). Returns TRUE if some
subject was removed, FALSE otherwise.
removeSubjectByTerm(term)Removes a subject by term. Returns TRUE if some subject was removed,
FALSE otherwise.
removeSubjectByIdentifier(identifier)Removes a subject by identifier. Returns TRUE if some subject was removed,
FALSE otherwise.
setNotes(notes)Set notes. HTML is not allowed
setCommunities(communities)Set a vector of character strings identifying communities
addCommunity(community)Adds a community to the record metadata. Return TRUE if added,
FALSE otherwise. The community should be set with the Zenodo id of the community. If not
recognized by Zenodo, the function will return an error. The list of communities can
fetched with the ZenodoManager and the function $getCommunities().
removedCommunity(community)Removes a community from the record metadata. Return TRUE if removed,
FALSE otherwise.