get_citation allows to get the styled citation for Zenodo record, identified by its DOI or concept DOI, and the style name

get_citation(
  doi,
  sandbox = FALSE,
  style = c("havard-cite-them-right", "apa", "modern-language-association", "vancouver",
    "chicago-fullnote-bibliography", "ieee", "bibtex"),
  logger = NULL
)

Arguments

doi

a Zenodo DOI or concept DOI

sandbox

Use the sandbox infrastructure. Default is FALSE

style

the style character string among. Possible values "havard-cite-them-right", "apa", "modern-language-association","vancouver","chicago-fullnote-bibliography", "ieee", or "bibtex".

logger

a logger to print messages. The logger can be either NULL, "INFO" (with minimum logs), or "DEBUG" (for complete curl http calls logs)

Value

an object of class data.frame giving the record versions including date, version number and version-specific DOI.

the record citation

Examples

# \dontrun{
 get_citation(doi = "10.5281/zenodo.2547036", style = "ieee")
#>  Number of records: 0
#> ! No record for DOI '10.5281/zenodo.2547036'!
#>  Try to get deposition by Zenodo specific record id '2547036'
#>  Number of records: 0
#> ! No record for id '2547036'!
#>  Number of records: 21
#>  Successfully fetched list of published records - page 1 (size = 10)
#>  Successfully fetched list of published records!
#>  Successfully fetched published record for concept DOI '10.5281/zenodo.2547036'!
#> Error in get_citation(doi = "10.5281/zenodo.2547036", style = "ieee"): object 'rec' not found
# }