get_zenodo allows to get a Zenodo record, identified by its DOI or concept DOI.

get_zenodo(doi, sandbox = FALSE, logger = NULL)

Arguments

doi

a Zenodo DOI or concept DOI

sandbox

Use the sandbox infrastructure. Default is FALSE

logger

a logger to print messages. The logger can be either NULL, "INFO" (with minimum logs), or "DEBUG" (for complete curl http calls logs)

Value

an object of class data.frame giving the record versions including date, version number and version-specific DOI.

object of class ZenodoRecord

Examples

# \dontrun{
 get_zenodo("10.5281/zenodo.2547036")
#>  Number of records: 0
#> ! No record for DOI '10.5281/zenodo.2547036'!
#>  Try to get deposition by Zenodo specific record id '2547036'
#>  Number of records: 0
#> ! No record for id '2547036'!
#>  Number of records: 21
#>  Successfully fetched list of published records - page 1 (size = 10)
#>  Successfully fetched list of published records!
#>  Successfully fetched published record for concept DOI '10.5281/zenodo.2547036'!
#> <ZenodoRecord>
#> ....|-- created: 2025-06-18T04:43:03.909846+00:00
#> ....|-- updated: 2025-06-18T04:43:04.159810+00:00
#> ....|-- revision_id: 4
#> ....|-- is_draft: FALSE
#> ....|-- is_published: TRUE
#> ....|-- status: published
#> ....|-- versions: 
#> ........|-- is_latest: FALSE
#> ........|-- index: 20
#> ....|-- access: 
#> ........|-- record: public
#> ........|-- files: public
#> ........|-- embargo: 
#> ............|-- active: FALSE
#> ............|-- reason: 
#> ........|-- status: open
#> ....|-- files: 
#> ........|-- zen4R-0.10.2.tar.gz: 
#> ............|-- filename: zen4R-0.10.2.tar.gz
#> ............|-- filesize: 135675
#> ............|-- checksum: af2e0b5f58056611795313a24c88cec3
#> ............|-- download: https://zenodo.org/api/records/15686902/files/zen4R-0.10.2.tar.gz/content
#> ........|-- zen4R-0.10.2.zip: 
#> ............|-- filename: zen4R-0.10.2.zip
#> ............|-- filesize: 149570
#> ............|-- checksum: ea58633ded9760dc55daeb3f37d5a4de
#> ............|-- download: https://zenodo.org/api/records/15686902/files/zen4R-0.10.2.zip/content
#> ....|-- id: 15686902
#> ....|-- links: 
#> ........|-- self: https://zenodo.org/api/records/15686902
#> ........|-- self_html: https://zenodo.org/records/15686902
#> ........|-- preview_html: https://zenodo.org/records/15686902?preview=1
#> ........|-- doi: https://doi.org/10.5281/zenodo.15686902
#> ........|-- self_doi: https://doi.org/10.5281/zenodo.15686902
#> ........|-- self_doi_html: https://zenodo.org/doi/10.5281/zenodo.15686902
#> ........|-- reserve_doi: https://zenodo.org/api/records/15686902/draft/pids/doi
#> ........|-- parent: https://zenodo.org/api/records/2547036
#> ........|-- parent_html: https://zenodo.org/records/2547036
#> ........|-- parent_doi: https://doi.org/10.5281/zenodo.2547036
#> ........|-- parent_doi_html: https://zenodo.org/doi/10.5281/zenodo.2547036
#> ........|-- self_iiif_manifest: https://zenodo.org/api/iiif/record:15686902/manifest
#> ........|-- self_iiif_sequence: https://zenodo.org/api/iiif/record:15686902/sequence/default
#> ........|-- files: https://zenodo.org/api/records/15686902/files
#> ........|-- media_files: https://zenodo.org/api/records/15686902/media-files
#> ........|-- archive: https://zenodo.org/api/records/15686902/files-archive
#> ........|-- archive_media: https://zenodo.org/api/records/15686902/media-files-archive
#> ........|-- latest: https://zenodo.org/api/records/15686902/versions/latest
#> ........|-- latest_html: https://zenodo.org/records/15686902/latest
#> ........|-- versions: https://zenodo.org/api/records/15686902/versions
#> ........|-- draft: https://zenodo.org/api/records/15686902/draft
#> ........|-- access_links: https://zenodo.org/api/records/15686902/access/links
#> ........|-- access_grants: https://zenodo.org/api/records/15686902/access/grants
#> ........|-- access_users: https://zenodo.org/api/records/15686902/access/users
#> ........|-- access_request: https://zenodo.org/api/records/15686902/access/request
#> ........|-- access: https://zenodo.org/api/records/15686902/access
#> ........|-- communities: https://zenodo.org/api/records/15686902/communities
#> ........|-- communities-suggestions: https://zenodo.org/api/records/15686902/communities-suggestions
#> ........|-- request_deletion: https://zenodo.org/api/records/15686902/request-deletion
#> ........|-- file_modification: https://zenodo.org/api/records/15686902/file-modification
#> ........|-- requests: https://zenodo.org/api/records/15686902/requests
#> ....|-- metadata: 
#> ........|-- resource_type: 
#> ............|-- id: software
#> ........|-- creators: 
#> ........|-- title: zen4R: R Interface to Zenodo REST API
#> ........|-- publisher: Zenodo
#> ........|-- publication_date: 2025-06-18
#> ........|-- subjects: 
#> ........|-- contributors: 
#> ........|-- languages: 
#> ........|-- version: 0.10.2
#> ........|-- rights: 
#> ........|-- description: <p>zen4R: R Interface to Zenodo REST API</p>
#> <p><a href="https://github.com/eblondel/zen4R/releases/tag/v0.10.2">https://github.com/eblondel/zen4R/releases/tag/v0.10.2</a></p>
#> ........|-- additional_descriptions: 
#> ........|-- funding: 
#> ........|-- custom: 
#> ............|-- code:codeRepository: https://github.com/eblondel/zen4R
#> ............|-- code:programmingLanguage: list(id = "r", title = list(en = "R"))
#> ............|-- code:developmentStatus: active 
#> ............|-- code:developmentStatus: list(en = "Active")
#> ....|-- parent: 
#> ........|-- id: 2547036
#> ........|-- access: 
#> ............|-- owned_by: 5183
#> ............|-- settings: FALSE 
#> ............|-- settings: FALSE 
#> ............|-- settings: NULL 
#> ............|-- settings: 0
#> ........|-- communities: 
#> ............|-- ids: 81c04e58-2563-4999-92ed-447ad997ac00 
#> ............|-- ids: f0a8b890-f97a-4eb2-9eac-8b8a712d3a6c
#> ............|-- default: 81c04e58-2563-4999-92ed-447ad997ac00
#> ............|-- entries: list(id = "81c04e58-2563-4999-92ed-447ad997ac00", created = "2022-03-17T22:49:56.776909+00:00", updated = "2022-03-17T22:49:56.776923+00:00", links = list(), revision_id = 0, slug = "openfair", metadata = list(title = "OpenFair"), access = list(visibility = "public", members_visibility = "public", member_policy = "open", record_submission_policy = "open", review_policy = "closed"), deletion_status = list(is_deleted = FALSE, status = "P"), children = list(allow = FALSE)) 
#> ............|-- entries: list(id = "f0a8b890-f97a-4eb2-9eac-8b8a712d3a6c", created = "2022-11-23T15:53:29.436323+00:00", updated = "2025-03-30T18:32:53.868593+00:00", links = list(), revision_id = 23, slug = "eu", metadata = list(title = "EU Open Research Repository", type = list(id = "organization", title = list(de = "Organisation", en = "Organization")), website = "https://research-and-innovation.ec.europa.eu", funding = list(list(funder = list(id = "00k4n6c32", name = "European Commission"))), organizations = list(list(
#>     id = "00k4n6c32", name = "European Commission", identifiers = list(list(identifier = "00k4n6c32", scheme = "ror"), list(identifier = "grid.270680.b", scheme = "grid"))))), access = list(visibility = "public", members_visibility = "public", member_policy = "open", record_submission_policy = "open", review_policy = "closed"), theme = list(style = list(font = list(size = "16px", family = "Arial, sans-serif", weight = 600), primaryColor = "#004494", secondaryColor = "#FFD617", tertiaryColor = "#e3eefd", 
#>     primaryTextColor = "#FFFFFF", secondaryTextColor = "#000000", tertiaryTextColor = "#1c5694", mainHeaderBackgroundColor = "#FFFFFF"), brand = "horizon", enabled = TRUE), deletion_status = list(is_deleted = FALSE, status = "P"), children = list(allow = TRUE))
#> ........|-- pids: 
#> ............|-- doi: 10.5281/zenodo.2547036 
#> ............|-- doi: datacite 
#> ............|-- doi: datacite
#> ....|-- pids: 
#> ........|-- doi: 
#> ............|-- identifier: 10.5281/zenodo.15686902
#> ............|-- provider: datacite
#> ............|-- client: datacite
#> ........|-- oai: 
#> ............|-- identifier: oai:zenodo.org:15686902
#> ............|-- provider: oai
#> ....|-- stats:
#>     ↓ this_version.downloads = 130
#>     ↓ this_version.unique_downloads = 87
#>     ↓ all_versions.downloads = 2623
#>     ↓ all_versions.unique_downloads = 1577
#>     👁 this_version.views = 137
#>     👁 this_version.unique_views = 132
#>     👁 all_versions.views = 3183
#>     👁 all_versions.unique_views = 2987
#>     ■ this_version.data_volume = 18527030
#>     ■ all_versions.data_volume = 139344007
# }